# NanoImgPro
Nanosensor Image Processor (NanoImgPro), a python-based image analysis tool for dopamine nanosensors 



NanoImgPro.py contains the main class to process files


example_batch_process.py contains an example batch processing file

Documentation can be found in the [docs](https://github.com/NicholasOuassil/NanoImgPro/tree/main/docs) folder. Download the repo and open the HTML file in a web browser (works with chrome)

In order to import the class you should run `from NanoImgPro.NanoImgPro import NanoImgPro `

currently version 0.2.3
